@@ -5,10 +5,10 @@
 */
 
 #include "potdbackend.h"
-#include "config-NetworkManagerQt.h"
 
 #include <QDBusConnection>
 #include <QFileDialog>
+#include <QNetworkInformation>
 #include <QStandardPaths> // For "Pictures" folder
 
 #include <KIO/CopyJob> // For "Save Image"
@@ -22,9 +22,7 @@ static int s_instanceCount = 0;
 
 PotdBackend::PotdBackend(QObject *parent)
     : QObject(parent)
-#if SUPPORT_METERED_DETECTION
-    , m_networkManagerQtAvailable(true)
-#endif
+    , m_networkInfomationAvailable(!QNetworkInformation::availableBackends().empty())
 {
     if (!s_engine) {
         Q_ASSERT(s_instanceCount == 0);
@@ -112,7 +110,7 @@ QString PotdBackend::localUrl() const
         return {};
     }
 
-    return m_client->m_data.wallpaperLocalUrl;
+    return m_client->m_localPath;
 }
 
 QUrl PotdBackend::infoUrl() const
@@ -121,7 +119,7 @@ QUrl PotdBackend::infoUrl() const
         return {};
     }
 
-    return m_client->m_data.wallpaperInfoUrl;
+    return m_client->m_infoUrl;
 }
 
 QUrl PotdBackend::remoteUrl() const
@@ -130,7 +128,7 @@ QUrl PotdBackend::remoteUrl() const
         return {};
     }
 
-    return m_client->m_data.wallpaperRemoteUrl;
+    return m_client->m_remoteUrl;
 }
 
 QString PotdBackend::title() const
@@ -139,7 +137,7 @@ QString PotdBackend::title() const
         return {};
     }
 
-    return m_client->m_data.wallpaperTitle;
+    return m_client->m_title;
 }
 
 QString PotdBackend::author() const
@@ -148,7 +146,7 @@ QString PotdBackend::author() const
         return {};
     }
 
-    return m_client->m_data.wallpaperAuthor;
+    return m_client->m_author;
 }
 
 int PotdBackend::doesUpdateOverMeteredConnection() const
@@ -166,17 +164,13 @@ void PotdBackend::setUpdateOverMeteredConnection(int value)
     }
 
     if (m_ready && m_client) {
-#if SUPPORT_METERED_DETECTION
         m_client->setUpdateOverMeteredConnection(m_doesUpdateOverMeteredConnection);
-#else
-        m_client->updateSource();
-#endif
     }
 }
 
 void PotdBackend::saveImage()
 {
-    if (m_client->m_data.wallpaperLocalUrl.isEmpty()) {
+    if (m_client->m_localPath.isEmpty()) {
         return;
     }
 
@@ -200,10 +194,10 @@ void PotdBackend::saveImage()
 
     QString defaultFileName = m_client->m_metadata.name().trimmed();
 
-    if (!m_client->m_data.wallpaperTitle.isEmpty()) {
-        defaultFileName += QLatin1Char('-') + m_client->m_data.wallpaperTitle.trimmed();
-        if (!m_client->m_data.wallpaperAuthor.isEmpty()) {
-            defaultFileName += QLatin1Char('-') + m_client->m_data.wallpaperAuthor.trimmed();
+    if (!m_client->m_title.isEmpty()) {
+        defaultFileName += QLatin1Char('-') + m_client->m_title.trimmed();
+        if (!m_client->m_author.isEmpty()) {
+            defaultFileName += QLatin1Char('-') + m_client->m_author.trimmed();
         }
     } else {
         // Use current date
@@ -230,7 +224,7 @@ void PotdBackend::saveImage()
 
     m_savedFolder = QUrl::fromLocalFile(QFileInfo(m_savedUrl.toLocalFile()).absolutePath());
 
-    KIO::CopyJob *copyJob = KIO::copy(QUrl::fromLocalFile(m_client->m_data.wallpaperLocalUrl), m_savedUrl, KIO::HideProgressInfo);
+    KIO::CopyJob *copyJob = KIO::copy(QUrl::fromLocalFile(m_client->m_localPath), m_savedUrl, KIO::HideProgressInfo);
     connect(copyJob, &KJob::finished, this, [this](KJob *job) {
         if (job->error()) {
             m_saveStatusMessage = job->errorText();
@@ -265,7 +259,6 @@ void PotdBackend::registerClient()
         return;
     }
 
-    connect(m_client, &PotdClient::imageChanged, this, &PotdBackend::imageChanged);
     connect(m_client, &PotdClient::loadingChanged, this, &PotdBackend::loadingChanged);
     connect(m_client, &PotdClient::localUrlChanged, this, &PotdBackend::localUrlChanged);
     connect(m_client, &PotdClient::infoUrlChanged, this, &PotdBackend::infoUrlChanged);
