@@ -9,6 +9,7 @@
 #include <chrono>
 
 #include <QDBusConnection>
+#include <QFileInfo>
 #include <QThreadPool>
 
 #include <KPluginFactory>
@@ -20,11 +21,13 @@ using namespace std::chrono_literals;
 
 namespace
 {
+static bool s_networkInformationAvailable = false;
 
-#if SUPPORT_METERED_DETECTION
 bool isUsingMeteredConnection()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+    if (!s_networkInformationAvailable) {
+        return false;
+    }
     const auto instance = QNetworkInformation::instance();
     if (instance->supports(QNetworkInformation::Feature::Metered)) {
         return instance->isMetered();
@@ -34,27 +37,14 @@ bool isUsingMeteredConnection()
             || transport == QNetworkInformation::TransportMedium::Bluetooth;
     }
     return false;
-#elif HAVE_NetworkManagerQt
-    const auto metered = NetworkManager::metered();
-    return metered == NetworkManager::Device::MeteredStatus::GuessYes //
-        || metered == NetworkManager::Device::MeteredStatus::Yes;
-#endif
-    Q_UNREACHABLE();
 }
-#endif // SUPPORT_METERED_DETECTION
 
 bool isNetworkConnected()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
     const auto instance = QNetworkInformation::instance();
     if (instance->supports(QNetworkInformation::Feature::Reachability) && instance->reachability() != QNetworkInformation::Reachability::Online) {
         return false;
     }
-#elif HAVE_NetworkManagerQt
-    if (NetworkManager::connectivity() != NetworkManager::Connectivity::Full) {
-        return false;
-    }
-#endif
     return true;
 }
 }
@@ -78,13 +68,9 @@ void PotdClient::updateSource(bool refresh)
     setLoading(true);
 
     // Check whether it is cached already...
-#if SUPPORT_METERED_DETECTION
     // Use cache even if it's outdated when using metered connection
     const bool ignoreAge = m_doesUpdateOverMeteredConnection == 0 && isUsingMeteredConnection();
     if ((!refresh || ignoreAge /* Allow force refresh only when no cached image is available */) && CachedProvider::isCached(m_identifier, m_args, ignoreAge)) {
-#else
-    if (!refresh && CachedProvider::isCached(m_identifier, m_args, false)) {
-#endif
         qCDebug(WALLPAPERPOTD) << "A local cache is available for" << m_identifier << "with arguments" << m_args;
 
         CachedProvider *provider = new CachedProvider(m_identifier, m_args, this);
@@ -93,7 +79,7 @@ void PotdClient::updateSource(bool refresh)
         return;
     }
 
-    if (auto url = CachedProvider::identifierToPath(m_identifier, m_args); QFile::exists(url)) {
+    if (auto url = CachedProvider::identifierToPath(m_identifier, m_args); QFileInfo::exists(url)) {
         setLocalUrl(url);
     }
 
@@ -108,7 +94,6 @@ void PotdClient::updateSource(bool refresh)
     }
 }
 
-#if SUPPORT_METERED_DETECTION
 void PotdClient::setUpdateOverMeteredConnection(int value)
 {
     // Don't return if values are the same because there can be multiple
@@ -118,9 +103,8 @@ void PotdClient::setUpdateOverMeteredConnection(int value)
     m_doesUpdateOverMeteredConnection = value;
     updateSource();
 }
-#endif
 
-void PotdClient::slotFinished(PotdProvider *provider)
+void PotdClient::slotFinished(PotdProvider *provider, const QImage &image)
 {
     setInfoUrl(provider->infoUrl());
     setRemoteUrl(provider->remoteUrl());
@@ -129,23 +113,25 @@ void PotdClient::slotFinished(PotdProvider *provider)
 
     // Store in cache if it's not the response of a CachedProvider
     if (qobject_cast<CachedProvider *>(provider) == nullptr) {
-        m_data.wallpaperImage = provider->image();
-        m_imageChanged = true;
-        SaveImageThread *thread = new SaveImageThread(m_identifier, m_args, m_data);
-        connect(thread, &SaveImageThread::done, this, &PotdClient::slotCachingFinished);
+        PotdProviderData data;
+        data.remoteUrl = provider->remoteUrl();
+        data.infoUrl = provider->infoUrl();
+        data.title = provider->title();
+        data.author = provider->author();
+        data.remoteUrl = provider->remoteUrl();
+        data.image = image;
+
+        SaveImageThread *thread = new SaveImageThread(m_identifier, m_args, data);
+        connect(thread, &SaveImageThread::done, this, &PotdClient::slotCached);
         QThreadPool::globalInstance()->start(thread);
     } else {
         // Is cache provider
-        setLocalUrl(CachedProvider::identifierToPath(m_identifier, m_args));
-        if (m_imageChanged) {
-            m_imageChanged = false;
-            Q_EMIT imageChanged();
-        }
+        setLocalUrl(provider->localPath());
         setLoading(false);
+        Q_EMIT done(this, true);
     }
 
     provider->deleteLater();
-    Q_EMIT done(this, true);
 }
 
 void PotdClient::slotError(PotdProvider *provider)
@@ -157,11 +143,11 @@ void PotdClient::slotError(PotdProvider *provider)
     Q_EMIT done(this, false);
 }
 
-void PotdClient::slotCachingFinished(const QString &, const PotdProviderData &data)
+void PotdClient::slotCached(const QString &localPath)
 {
-    setLocalUrl(data.wallpaperLocalUrl);
-    Q_EMIT imageChanged();
+    setLocalUrl(localPath);
     setLoading(false);
+    Q_EMIT done(this, false);
 }
 
 void PotdClient::setLoading(bool status)
@@ -176,57 +162,59 @@ void PotdClient::setLoading(bool status)
 
 void PotdClient::setLocalUrl(const QString &urlString)
 {
-    if (m_data.wallpaperLocalUrl == urlString) {
+    if (m_localPath == urlString) {
         return;
     }
 
-    m_data.wallpaperLocalUrl = urlString;
+    m_localPath = urlString;
     Q_EMIT localUrlChanged();
 }
 
 void PotdClient::setInfoUrl(const QUrl &url)
 {
-    if (m_data.wallpaperInfoUrl == url) {
+    if (m_infoUrl == url) {
         return;
     }
 
-    m_data.wallpaperInfoUrl = url;
+    m_infoUrl = url;
     Q_EMIT infoUrlChanged();
 }
 
 void PotdClient::setRemoteUrl(const QUrl &url)
 {
-    if (m_data.wallpaperRemoteUrl == url) {
+    if (m_remoteUrl == url) {
         return;
     }
 
-    m_data.wallpaperRemoteUrl = url;
+    m_remoteUrl = url;
     Q_EMIT remoteUrlChanged();
 }
 
 void PotdClient::setTitle(const QString &title)
 {
-    if (m_data.wallpaperTitle == title) {
+    if (m_title == title) {
         return;
     }
 
-    m_data.wallpaperTitle = title;
+    m_title = title;
     Q_EMIT titleChanged();
 }
 
 void PotdClient::setAuthor(const QString &author)
 {
-    if (m_data.wallpaperAuthor == author) {
+    if (m_author == author) {
         return;
     }
 
-    m_data.wallpaperAuthor = author;
+    m_author = author;
     Q_EMIT authorChanged();
 }
 
 PotdEngine::PotdEngine(QObject *parent)
     : QObject(parent)
 {
+    qRegisterMetaType<PotdProviderData>();
+
     loadPluginMetaData();
 
     connect(&m_checkDatesTimer, &QTimer::timeout, this, &PotdEngine::forceUpdateSource);
@@ -243,18 +231,7 @@ PotdEngine::PotdEngine(QObject *parent)
                                          QStringLiteral("PrepareForSleep"),
                                          this,
                                          SLOT(slotPrepareForSleep(bool)));
-
-#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
-    const auto instance = QNetworkInformation::instance();
-    if (instance->supports(QNetworkInformation::Feature::Metered)) {
-        connect(instance, &QNetworkInformation::isMeteredChanged, this, &PotdEngine::slotIsMeteredChanged);
-    }
-    if (instance->supports(QNetworkInformation::Feature::Reachability)) {
-        connect(instance, &QNetworkInformation::reachabilityChanged, this, &PotdEngine::slotReachabilityChanged);
-    }
-#elif HAVE_NetworkManagerQt
-    connect(NetworkManager::notifier(), &NetworkManager::Notifier::connectivityChanged, this, &PotdEngine::slotConnectivityChanged);
-#endif
+    loadNetworkInformation();
 }
 
 PotdClient *PotdEngine::registerClient(const QString &identifier, const QVariantList &args)
@@ -371,7 +348,6 @@ void PotdEngine::slotPrepareForSleep(bool sleep)
     forceUpdateSource();
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
 void PotdEngine::slotReachabilityChanged(QNetworkInformation::Reachability newReachability)
 {
     if (newReachability == QNetworkInformation::Reachability::Online) {
@@ -388,15 +364,23 @@ void PotdEngine::slotIsMeteredChanged(bool isMetered)
 
     updateSource(false);
 }
-#elif HAVE_NetworkManagerQt
-void PotdEngine::slotConnectivityChanged(NetworkManager::Connectivity connectivity)
+
+void PotdEngine::loadNetworkInformation()
 {
-    if (connectivity == NetworkManager::Connectivity::Full) {
-        qCDebug(WALLPAPERPOTD) << "Network is connected.";
-        updateSource(false);
+    if (!QNetworkInformation::loadDefaultBackend()) {
+        return;
+    }
+
+    s_networkInformationAvailable = true;
+    const auto instance = QNetworkInformation::instance();
+
+    if (instance->supports(QNetworkInformation::Feature::Metered)) {
+        connect(instance, &QNetworkInformation::isMeteredChanged, this, &PotdEngine::slotIsMeteredChanged);
+    }
+    if (instance->supports(QNetworkInformation::Feature::Reachability)) {
+        connect(instance, &QNetworkInformation::reachabilityChanged, this, &PotdEngine::slotReachabilityChanged);
     }
 }
-#endif
 
 void PotdEngine::loadPluginMetaData()
 {
